==> openjdk11-src-11.0.17.u1-1.0-i486.pkg.tar.zst: jdk.localedata/sun/util/resources/cldr/ext/TimeZoneNames_es_MX.java <==
/*
 * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.TimeZoneNamesBundle;

public class TimeZoneNames_es_MX extends TimeZoneNamesBundle {
    @Override
    protected final Object[][] getContents() {
        final String[] Cocos = new String[] {
               "hora de las Islas Cocos",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Easter = new String[] {
               "hora est\u00e1ndar de la isla de Pascua",
               "",
               "hora de verano de la isla de Pascua",
               "",
               "hora de la isla de Pascua",
               "",
            };
        final String[] ETC_UTC = new String[] {
               "Tiempo Universal Coordinado",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Macquarie = new String[] {
               "hora de la isla Macquarie",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Gilbert_Islands = new String[] {
               "hora de las islas Gilbert",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] America_Mountain = new String[] {
               "hora est\u00e1ndar de las Monta\u00f1as Rocosas",
               "",
               "hora de verano de las Monta\u00f1as Rocosas",
               "",
               "hora de las Monta\u00f1as Rocosas",
               "",
            };
        final String[] Wake = new String[] {
               "hora de la isla Wake",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Falkland = new String[] {
               "hora est\u00e1ndar de las islas Malvinas",
               "",
               "hora de verano de las islas Malvinas",
               "",
               "hora de las islas Malvinas",
               "",
            };
        final String[] Europe_Western = new String[] {
               "hora est\u00e1ndar de Europa occidental",
               "\u2205\u2205\u2205",
               "hora de verano de Europa occidental",
               "\u2205\u2205\u2205",
               "hora de Europa occidental",
               "\u2205\u2205\u2205",
            };
        final String[] Solomon = new String[] {
               "hora de las Islas Salom\u00f3n",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Norfolk = new String[] {
               "hora de la isla Norfolk",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Irkutsk = new String[] {
               "hora est\u00e1ndar de Irkutsh",
               "",
               "hora de verano de Irkutsh",
               "",
               "hora de Irkutsk",
               "",
            };
        final String[] Marshall_Islands = new String[] {
               "hora de las Islas Marshall",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Europe_Eastern = new String[] {
               "hora est\u00e1ndar de Europa oriental",
               "\u2205\u2205\u2205",
               "hora de verano de Europa oriental",
               "\u2205\u2205\u2205",
               "hora de Europa oriental",
               "\u2205\u2205\u2205",
            };
        final String[] Apia = new String[] {
               "hora est\u00e1ndar de Apia",
               "",
               "hora de verano de Apia",
               "",
               "hora de Apia",
               "",
            };
        final String[] Argentina_Western = new String[] {
               "hora est\u00e1ndar de Argentina occidental",
               "",
               "hora de verano de Argentina occidental",
               "",
               "hora de Argentina occidental",
               "",
            };
        final String[] Myanmar = new String[] {
               "hora de Myanmar (Birmania)",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Christmas = new String[] {
               "hora de la isla de Navidad",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Pyongyang = new String[] {
               "hora de Pyongyang",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Cook = new String[] {
               "hora est\u00e1ndar de las Islas Cook",
               "",
               "hora de verano media de las Islas Cook",
               "",
               "hora de las Islas Cook",
               "",
            };
        final Object[][] data = new Object[][] {
            { "America/Denver", America_Mountain },
            { "America/Phoenix", America_Mountain },
            { "Africa/Casablanca", Europe_Western },
            { "Europe/Bucharest", Europe_Eastern },
            { "UTC", ETC_UTC },
            { "Pacific/Kwajalein", Marshall_Islands },
            { "Africa/El_Aaiun", Europe_Western },
            { "Africa/Cairo", Europe_Eastern },
            { "Pacific/Rarotonga", Cook },
            { "Europe/Chisinau", Europe_Eastern },
            { "PNT", America_Mountain },
            { "Europe/Helsinki", Europe_Eastern },
            { "Asia/Beirut", Europe_Eastern },
            { "America/Ojinaga", America_Mountain },
            { "Europe/Tallinn", Europe_Eastern },
            { "Asia/Damascus", Europe_Eastern },
            { "MIT", Apia },
            { "America/Argentina/San_Luis", Argentina_Western },
            { "ART", Europe_Eastern },
            { "America/Yellowknife", America_Mountain },
            { "Europe/Zaporozhye", Europe_Eastern },
            { "timezone.excity.Africa/Bujumbura", "Buyumbura" },
            { "timezone.excity.Asia/Dushanbe", "Dusamb\u00e9" },
            { "Atlantic/Madeira", Europe_Western },
            { "timezone.excity.Asia/Pyongyang", "Piongyang" },
            { "Europe/Uzhgorod", Europe_Eastern },
            { "Europe/Sofia", Europe_Eastern },
            { "America/Creston", America_Mountain },
            { "Indian/Christmas", Christmas },
            { "Africa/Tripoli", Europe_Eastern },
            { "timezone.excity.Pacific/Honolulu", "Honolulu" },
            { "America/Inuvik", America_Mountain },
            { "Antarctica/Macquarie", Macquarie },
            { "Asia/Nicosia", Europe_Eastern },
            { "Europe/Kaliningrad", Europe_Eastern },
            { "SystemV/MST7MDT", America_Mountain },
            { "timezone.excity.Pacific/Wake", "Wake" },
            { "Asia/Pyongyang", Pyongyang },
            { "Europe/Lisbon", Europe_Western },
            { "Asia/Gaza", Europe_Eastern },
            { "timezone.excity.Africa/Accra", "Acra" },
            { "Atlantic/Faeroe", Europe_Western },
            { "Pacific/Easter", Easter },
            { "Atlantic/Canary", Europe_Western },
            { "Asia/Rangoon", Myanmar },
            { "Pacific/Norfolk", Norfolk },
            { "Indian/Cocos", Cocos },
            { "Pacific/Tarawa", Gilbert_Islands },
            { "timezone.excity.Asia/Qatar", "Qatar" },
            { "timezone.excity.Europe/Kirov", "Kirov" },
            { "America/Edmonton", America_Mountain },
            { "SystemV/MST7", America_Mountain },
            { "America/Fort_Nelson", America_Mountain },
            { "Europe/Riga", Europe_Eastern },
            { "Europe/Kiev", Europe_Eastern },
            { "Asia/Hebron", Europe_Eastern },
            { "timezone.excity.Africa/Khartoum", "Jartum" },
            { "America/Boise", America_Mountain },
            { "timezone.excity.Africa/Dar_es_Salaam", "Dar es-Salaam" },
            { "America/Dawson_Creek", America_Mountain },
            { "Europe/Mariehamn", Europe_Eastern },
            { "Pacific/Wake", Wake },
            { "Asia/Irkutsk", Irkutsk },
            { "Europe/Vilnius", Europe_Eastern },
            { "America/Shiprock", America_Mountain },
            { "timezone.excity.America/Rio_Branco", "Rio Branco" },
            { "timezone.excity.America/Fort_Nelson", "Fort Nelson" },
            { "Asia/Amman", Europe_Eastern },
            { "Etc/UTC", ETC_UTC },
            { "Pacific/Apia", Apia },
            { "America/Cambridge_Bay", America_Mountain },
            { "MST7MDT", America_Mountain },
            { "timezone.excity.America/St_Thomas", "St. Thomas" },
            { "Pacific/Majuro", Marshall_Islands },
            { "timezone.excity.Africa/Conakry", "Conakri" },
            { "SST", Solomon },
            { "Pacific/Guadalcanal", Solomon },
            { "Europe/Athens", Europe_Eastern },
            { "Atlantic/Stanley", Falkland },
            { "timezone.excity.Asia/Almaty", "Almat\u00fd" },
        };
        return data;
    }
}

==> openjdk11-src-11.0.19.u7-1.0-i486.pkg.tar.zst: jdk.localedata/sun/util/resources/cldr/ext/TimeZoneNames_es_MX.java <==
/*
 * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.TimeZoneNamesBundle;

public class TimeZoneNames_es_MX extends TimeZoneNamesBundle {
    @Override
    protected final Object[][] getContents() {
        final String[] Cocos = new String[] {
               "hora de las Islas Cocos",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Easter = new String[] {
               "hora est\u00e1ndar de la isla de Pascua",
               "",
               "hora de verano de la isla de Pascua",
               "",
               "hora de la isla de Pascua",
               "",
            };
        final String[] ETC_UTC = new String[] {
               "Tiempo Universal Coordinado",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Macquarie = new String[] {
               "hora de la isla Macquarie",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Gilbert_Islands = new String[] {
               "hora de las islas Gilbert",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] America_Mountain = new String[] {
               "hora est\u00e1ndar de las Monta\u00f1as Rocosas",
               "",
               "hora de verano de las Monta\u00f1as Rocosas",
               "",
               "hora de las Monta\u00f1as Rocosas",
               "",
            };
        final String[] Wake = new String[] {
               "hora de la isla Wake",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Falkland = new String[] {
               "hora est\u00e1ndar de las islas Malvinas",
               "",
               "hora de verano de las islas Malvinas",
               "",
               "hora de las islas Malvinas",
               "",
            };
        final String[] Europe_Western = new String[] {
               "hora est\u00e1ndar de Europa occidental",
               "\u2205\u2205\u2205",
               "hora de verano de Europa occidental",
               "\u2205\u2205\u2205",
               "hora de Europa occidental",
               "\u2205\u2205\u2205",
            };
        final String[] Solomon = new String[] {
               "hora de las Islas Salom\u00f3n",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Norfolk = new String[] {
               "hora de la isla Norfolk",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Irkutsk = new String[] {
               "hora est\u00e1ndar de Irkutsh",
               "",
               "hora de verano de Irkutsh",
               "",
               "hora de Irkutsk",
               "",
            };
        final String[] Marshall_Islands = new String[] {
               "hora de las Islas Marshall",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Europe_Eastern = new String[] {
               "hora est\u00e1ndar de Europa oriental",
               "\u2205\u2205\u2205",
               "hora de verano de Europa oriental",
               "\u2205\u2205\u2205",
               "hora de Europa oriental",
               "\u2205\u2205\u2205",
            };
        final String[] Apia = new String[] {
               "hora est\u00e1ndar de Apia",
               "",
               "hora de verano de Apia",
               "",
               "hora de Apia",
               "",
            };
        final String[] Argentina_Western = new String[] {
               "hora est\u00e1ndar de Argentina occidental",
               "",
               "hora de verano de Argentina occidental",
               "",
               "hora de Argentina occidental",
               "",
            };
        final String[] Myanmar = new String[] {
               "hora de Myanmar (Birmania)",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Christmas = new String[] {
               "hora de la isla de Navidad",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Pyongyang = new String[] {
               "hora de Pyongyang",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Cook = new String[] {
               "hora est\u00e1ndar de las Islas Cook",
               "",
               "hora de verano media de las Islas Cook",
               "",
               "hora de las Islas Cook",
               "",
            };
        final Object[][] data = new Object[][] {
            { "America/Denver", America_Mountain },
            { "America/Phoenix", America_Mountain },
            { "Africa/Casablanca", Europe_Western },
            { "Europe/Bucharest", Europe_Eastern },
            { "UTC", ETC_UTC },
            { "Pacific/Kwajalein", Marshall_Islands },
            { "Africa/El_Aaiun", Europe_Western },
            { "Africa/Cairo", Europe_Eastern },
            { "Pacific/Rarotonga", Cook },
            { "Europe/Chisinau", Europe_Eastern },
            { "PNT", America_Mountain },
            { "Europe/Helsinki", Europe_Eastern },
            { "Asia/Beirut", Europe_Eastern },
            { "Europe/Tallinn", Europe_Eastern },
            { "Asia/Damascus", Europe_Eastern },
            { "MIT", Apia },
            { "America/Argentina/San_Luis", Argentina_Western },
            { "ART", Europe_Eastern },
            { "America/Yellowknife", America_Mountain },
            { "Europe/Zaporozhye", Europe_Eastern },
            { "timezone.excity.Africa/Bujumbura", "Buyumbura" },
            { "timezone.excity.Asia/Dushanbe", "Dusamb\u00e9" },
            { "Atlantic/Madeira", Europe_Western },
            { "timezone.excity.Asia/Pyongyang", "Piongyang" },
            { "Europe/Uzhgorod", Europe_Eastern },
            { "Europe/Sofia", Europe_Eastern },
            { "America/Creston", America_Mountain },
            { "Indian/Christmas", Christmas },
            { "Africa/Tripoli", Europe_Eastern },
            { "timezone.excity.Pacific/Honolulu", "Honolulu" },
            { "America/Inuvik", America_Mountain },
            { "Antarctica/Macquarie", Macquarie },
            { "Asia/Nicosia", Europe_Eastern },
            { "Europe/Kaliningrad", Europe_Eastern },
            { "SystemV/MST7MDT", America_Mountain },
            { "timezone.excity.Pacific/Wake", "Wake" },
            { "Asia/Pyongyang", Pyongyang },
            { "Europe/Lisbon", Europe_Western },
            { "Asia/Gaza", Europe_Eastern },
            { "timezone.excity.Africa/Accra", "Acra" },
            { "Atlantic/Faeroe", Europe_Western },
            { "Pacific/Easter", Easter },
            { "Atlantic/Canary", Europe_Western },
            { "Asia/Rangoon", Myanmar },
            { "America/Ciudad_Juarez", America_Mountain },
            { "Pacific/Norfolk", Norfolk },
            { "Indian/Cocos", Cocos },
            { "Pacific/Tarawa", Gilbert_Islands },
            { "timezone.excity.Asia/Qatar", "Qatar" },
            { "timezone.excity.Europe/Kirov", "Kirov" },
            { "America/Edmonton", America_Mountain },
            { "SystemV/MST7", America_Mountain },
            { "America/Fort_Nelson", America_Mountain },
            { "Europe/Riga", Europe_Eastern },
            { "Europe/Kiev", Europe_Eastern },
            { "Asia/Hebron", Europe_Eastern },
            { "timezone.excity.Africa/Khartoum", "Jartum" },
            { "America/Boise", America_Mountain },
            { "timezone.excity.Africa/Dar_es_Salaam", "Dar es-Salaam" },
            { "America/Dawson_Creek", America_Mountain },
            { "Europe/Mariehamn", Europe_Eastern },
            { "Pacific/Wake", Wake },
            { "Asia/Irkutsk", Irkutsk },
            { "Europe/Vilnius", Europe_Eastern },
            { "America/Shiprock", America_Mountain },
            { "timezone.excity.America/Rio_Branco", "Rio Branco" },
            { "timezone.excity.America/Fort_Nelson", "Fort Nelson" },
            { "Asia/Amman", Europe_Eastern },
            { "Etc/UTC", ETC_UTC },
            { "Pacific/Apia", Apia },
            { "America/Cambridge_Bay", America_Mountain },
            { "MST7MDT", America_Mountain },
            { "timezone.excity.America/St_Thomas", "St. Thomas" },
            { "Pacific/Majuro", Marshall_Islands },
            { "timezone.excity.Africa/Conakry", "Conakri" },
            { "SST", Solomon },
            { "Pacific/Guadalcanal", Solomon },
            { "Europe/Athens", Europe_Eastern },
            { "Atlantic/Stanley", Falkland },
            { "timezone.excity.Asia/Almaty", "Almat\u00fd" },
        };
        return data;
    }
}
